@@ -10,14 +10,14 @@ from __future__ import annotations
 
 __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
 
-import warnings
-from typing import Tuple, List
-
-import uuid
 import base64
+import contextlib
+import uuid
+import warnings
+from typing import List, Tuple
+
 import dash
 import plotly.graph_objects as go
-from flask_cors import cross_origin
 from jupyter_dash import JupyterDash
 from plotly.basedatatypes import BaseFigure
 from trace_updater import TraceUpdater
@@ -48,6 +48,11 @@ class JupyterDashPersistentInlineOutput(JupyterDash):
         the :func:`FigureResampler.show_dash <plotly_resampler.figure_resampler.FigureResampler.show_dash>`
         method. However, the mode should be passed as ``"inline"`` since this subclass
         overwrites the inline behavior.
+
+    .. Note::
+        This subclass utilizes the optional ``flask_cors`` package to detect whether the
+        server is alive or not.
+
     """
 
     def __init__(self, *args, **kwargs):
@@ -55,11 +60,14 @@ class JupyterDashPersistentInlineOutput(JupyterDash):
 
         self._uid = str(uuid.uuid4())  # A new unique id for each app
 
-        # Mimic the _alive_{token} endpoint but with cors
-        @self.server.route(f"/_is_alive_{self._uid}", methods=["GET"])
-        @cross_origin(origin=["*"], allow_headers=["Content-Type"])
-        def broadcast_alive():
-            return "Alive"
+        with contextlib.suppress(ImportWarning, ModuleNotFoundError):
+            from flask_cors import cross_origin
+
+            # Mimic the _alive_{token} endpoint but with cors
+            @self.server.route(f"/_is_alive_{self._uid}", methods=["GET"])
+            @cross_origin(origin=["*"], allow_headers=["Content-Type"])
+            def broadcast_alive():
+                return "Alive"
 
     def _display_inline_output(self, dashboard_url, width, height):
         """Display the dash app persistent inline in the notebook.
@@ -71,6 +79,14 @@ class JupyterDashPersistentInlineOutput(JupyterDash):
         # TODO: add option to opt out of this
         from IPython.display import display
 
+        try:
+            import flask_cors  # noqa: F401
+        except (ImportError, ModuleNotFoundError):
+            warnings.warn(
+                "'flask_cors' is not installed. The persistent inline output will "
+                + " not be able to detect whether the server is alive or not."
+            )
+
         # Get the image from the dashboard and encode it as base64
         fig = self.layout.children[0].figure  # is stored there in the show_dash method
         f_width = 1000 if fig.layout.width is None else fig.layout.width
@@ -348,7 +364,9 @@ class FigureResampler(AbstractFigureAggregator, go.Figure):
                 environments, browsers, etc.
 
                 .. note::
-                    This mode requires the ``kaleido`` package.
+                    This mode requires the ``kaleido`` and ``flask_cors`` package.
+                    Install them : ``pip install plotly_resampler[inline_persistent]``
+                    or ``pip install kaleido flask_cors``.
 
               * ``"jupyterlab"``: The app will be displayed in a dedicated tab in the
                 JupyterLab interface. Requires JupyterLab and the ``jupyterlab-dash``
@@ -377,7 +395,7 @@ class FigureResampler(AbstractFigureAggregator, go.Figure):
             mode is None or mode in available_modes
         ), f"mode must be one of {available_modes}"
         graph_properties = {} if graph_properties is None else graph_properties
-        assert "config" not in graph_properties.keys()  # There is a param for config
+        assert "config" not in graph_properties  # There is a param for config
 
         # 0. Check if the traces need to be updated when there is a xrange set
         # This will be the case when the users has set a xrange (via the `update_layout`
@@ -388,7 +406,7 @@ class FigureResampler(AbstractFigureAggregator, go.Figure):
             if x_range:  # when not None
                 relayout_dict[f"{xaxis_str}.range[0]"] = x_range[0]
                 relayout_dict[f"{xaxis_str}.range[1]"] = x_range[1]
-        if len(relayout_dict):
+        if relayout_dict:  # when not empty
             update_data = self.construct_update_data(relayout_dict)
 
             if not self._is_no_update(update_data):  # when there is an update
